function z = membrana(bordo, carico, r)
	% z = membrana(bordo, carico, r)
	% Esegue r passi del metodo di Jacobi per il problema della membrana elastica, senza costruire esplicitamente la matrice A mn x mn
	% bordo: matrice m x n con i valori sul bordo uguali alle altezze della membrana sul bordo
	% carico: matrice m x n tale che carico(i,j) è il peso posto nel punto (i,j)
	% z: matrice m x n con i valori approssimati delle altezze della membrana calcolati dopo r passi del metodo di Jacobi

	[m, n] = size(bordo);

	% Inizializzo z prendendo i valori sul bordo da bordo (i valori non sul bordo sono posti a zero):
	z = zeros(m, n);
	z(1, :) = bordo(1, :);
	z(end, :) = bordo(end, :);
	z(:, 1) = bordo(:, 1);
	z(:, end) = bordo(:, end);

	% Iterazioni:
	for k = 1:r
		% Versione vettorizzata (Jacobi):
		z(2:end-1, 2:end-1) = -1/4 * (carico(2:end-1, 2:end-1) - z(1:end-2, 2:end-1) - z(3:end, 2:end-1) - z(2:end-1, 1:end-2) - z(2:end-1, 3:end));

		% Alternativa: versione sequenziale (Jacobi):
		% z_new = z;
		% for i = 2:m-1
		% 	for j = 2:n-1
		% 		z_new(i, j) = -1/4 * (carico(i,j) - z(i-1, j) - z(i+1, j) - z(i, j-1) - z(i, j+1));
		% 	end
		% end
		% z = z_new

		% Alternativa: metodo di Gauss-Seidel:
		% Notare che z(i-1, j) e z(i, j-1) contengono già il valore aggiornato
		% for i = 2:m-1
		% 	for j = 2:n-1
		% 		z(i, j) = -1/4 * (carico(i,j) - z(i-1, j) - z(i+1, j) - z(i, j-1) - z(i, j+1));
		% 	end
		% end
	end



end
